# DeviceCalibrationRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**octoprint_device** | **int** |  | 
**fps** | **float** |  | [optional] 
**xy** | **dict(str, object)** |  | [optional] 
**height** | **int** |  | [optional] 
**width** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


